Module client

Module client 

Structs

AuthConfig
Structured authentication configuration for TradingViewClient.
DefaultWebSocketConnector
Endpoints
Typed endpoint configuration for the TradingView surfaces used by the client.
EndpointsBuilder
Use builder syntax to set the inputs and finish with build().
HistoryBatchCompletedEvent
HistoryClientConfig
HistoryClientConfigBuilder
Use builder syntax to set the inputs and finish with build().
HttpRequestCompletedEvent
HttpRequestFailedEvent
RequestBudget
RequestBudgetBuilder
Use builder syntax to set the inputs and finish with build().
RetryConfig
RetryConfigBuilder
Use builder syntax to set the inputs and finish with build().
SnapshotBatchConfig
SnapshotBatchConfigBuilder
Use builder syntax to set the inputs and finish with build().
TradingViewClient
High-level entry point for TradingView screener, search, quote, and history data.
TradingViewClientBuilder
Use builder syntax to set the inputs and finish with build().
TradingViewClientConfig
TradingViewClientConfigBuilder
Use builder syntax to set the inputs and finish with build().
TransportConfig
TransportConfigBuilder
Use builder syntax to set the inputs and finish with build().
WebSocketConnectedEvent
WebSocketConnectionFailedEvent

Enums

AuthMode
Explicit authentication modes for TradingView HTTP and websocket flows.
ClientEvent
HistoryBatchMode
RetryJitter
SnapshotBatchStrategy

Traits

ClientObserver
WebSocketConnector

Type Aliases

WebSocketConnectFuture