Structs
- Auth
Config - Structured authentication configuration for
TradingViewClient. - Default
WebSocket Connector - Endpoints
- Typed endpoint configuration for the TradingView surfaces used by the client.
- Endpoints
Builder - Use builder syntax to set the inputs and finish with
build(). - History
Batch Completed Event - History
Client Config - History
Client Config Builder - Use builder syntax to set the inputs and finish with
build(). - Http
Request Completed Event - Http
Request Failed Event - Request
Budget - Request
Budget Builder - Use builder syntax to set the inputs and finish with
build(). - Retry
Config - Retry
Config Builder - Use builder syntax to set the inputs and finish with
build(). - Snapshot
Batch Config - Snapshot
Batch Config Builder - Use builder syntax to set the inputs and finish with
build(). - Trading
View Client - High-level entry point for TradingView screener, search, quote, and history data.
- Trading
View Client Builder - Use builder syntax to set the inputs and finish with
build(). - Trading
View Client Config - Trading
View Client Config Builder - Use builder syntax to set the inputs and finish with
build(). - Transport
Config - Transport
Config Builder - Use builder syntax to set the inputs and finish with
build(). - WebSocket
Connected Event - WebSocket
Connection Failed Event
Enums
- Auth
Mode - Explicit authentication modes for TradingView HTTP and websocket flows.
- Client
Event - History
Batch Mode - Retry
Jitter - Snapshot
Batch Strategy